# !/usr/bin/env python
#  -*- coding: UTF-8 -*-

__version__ = "0.7"  # LATEST? =>  https://pypi.org/project/dimcli/
__copyright__ = "CopyRight (C) 2018-2020 by Michele Pasin"
__license__ = "MIT"
__author__ = "Michele Pasin"
__author_email__ = "michele dot pasin at gmail dot com"

USAGE = "dimcli [options]"
VERSION = "v" + __version__
AGENT = "%s/%s" % (__name__, __version__)
